@@ -72,18 +72,11 @@ fn run(matches: &ArgMatches) -> Result<()> {
     let pathspecs: Vec<&Path> = if let Some(pathspecs) = matches.get_many::<PathBuf>("pathspecs") {
         pathspecs.map(PathBuf::as_path).collect()
     } else {
-        let prefix = if let Some(prefix_result) = repo.prefix() {
-            Some(prefix_result.context("determining Git prefix")?)
-        } else {
-            None
-        };
+        let prefix = repo.prefix().context("determining Git prefix")?;
 
         let mut paths: Vec<&Path> = Vec::new();
         pathsbuf = stupid
-            .diff_index_names(
-                stack.get_branch_head().tree_id()?.detach(),
-                prefix.as_deref(),
-            )
+            .diff_index_names(stack.get_branch_head().tree_id()?.detach(), prefix)
             .context("getting modified files")?;
 
         for path_bytes in pathsbuf.split_str(b"\0") {
