@@ -209,8 +209,8 @@ impl<'repo> StackState<'repo> {
             (self.make_tree(repo, None)?, None)
         };
         let config = repo.config_snapshot();
-        let committer = repo.get_committer()?;
-        let author = repo.get_author()?;
+        let committer = repo.get_committer()?.to_owned()?;
+        let author = repo.get_author()?.to_owned()?;
 
         let simplified_parents: Vec<gix::ObjectId> = match &self.prev {
             Some(prev_commit) => {
@@ -231,8 +231,8 @@ impl<'repo> StackState<'repo> {
         };
 
         let simplified_parent_id = repo.commit_with_options(
-            author,
-            committer,
+            &author,
+            &committer,
             &message,
             state_tree_id,
             simplified_parents,
@@ -263,8 +263,8 @@ impl<'repo> StackState<'repo> {
             let parent_group_oids =
                 parent_oids.drain(parent_oids.len() - MAX_PARENTS..parent_oids.len());
             let group_oid = repo.commit_with_options(
-                author,
-                committer,
+                &author,
+                &committer,
                 &Message::from("parent grouping"),
                 state_tree_id,
                 parent_group_oids,
@@ -276,8 +276,8 @@ impl<'repo> StackState<'repo> {
         parent_oids.insert(0, simplified_parent_id);
 
         let commit_oid = repo.commit_with_options(
-            author,
-            committer,
+            &author,
+            &committer,
             &message,
             state_tree_id,
             parent_oids,
