@@ -43,4 +43,22 @@ test_expect_success 'Rebase to same base message' '
     grep "info: Already based on .*(master)" out
 '
 
+test_expect_success 'Rebase without argument' '
+    test_must_fail stg rebase 2>out &&
+    grep -q "error: there is no tracking information for the current branch" out &&
+    git checkout master &&
+    echo bar >>file2 &&
+    git add file2 &&
+    git commit -m c &&
+    git remote add origin "file://$(pwd)" &&
+    git fetch origin &&
+    git checkout stack &&
+    git branch --set-upstream-to=origin/master &&
+    stg rebase 2>out &&
+    grep -E "info: Rebasing to .*\(master( origin/HEAD)? origin/master\)" out &&
+    test $(stg series --applied -c) = 1 &&
+    grep bar file1 &&
+    grep bar file2
+'
+
 test_done
