@@ -5,9 +5,9 @@ test_description='pre-commit hook'
 . ./test-lib.sh
 
 test_expect_success 'Initialise StGit' '
-    stg new -m "pre-commit-patch"
+    stg new -m "pre-commit-patch" &&
     echo "new file" >>file &&
-    git add file
+    git add file &&
     stg refresh
 '
 
@@ -42,19 +42,19 @@ assert_pre_commit_hook_did_not_run() {
 
 test_expect_success 'refresh --no-verify with succeeding hook' '
     echo "no-verify pre-commit-hook-success" >>file &&
-    stg refresh --no-verify
+    stg refresh --no-verify &&
     assert_pre_commit_hook_did_not_run
 '
 
 test_expect_success 'refresh --no-verify with path limiting, succeeding hook' '
     echo "no-verify pre-commit-hook-path-limiting-success" >>file &&
-    stg refresh file --no-verify
+    stg refresh file --no-verify &&
     assert_pre_commit_hook_did_not_run
 '
 
 test_expect_success 'refresh with succeeding hook' '
     echo "pre-commit-hook-success" >>file &&
-    stg refresh
+    stg refresh &&
     assert_pre_commit_hook_did_run
 '
 
@@ -71,7 +71,7 @@ test_expect_success 'refresh from subdir with succeeding hook' '
 
 test_expect_success 'refresh with path limiting, succeeding hook' '
     echo "pre-commit-hook-path-limiting-success" >>file &&
-    stg refresh file
+    stg refresh file &&
     assert_pre_commit_hook_did_run
 '
 
@@ -79,7 +79,7 @@ git config core.hooksPath .my-hooks
 mv "$HOOKDIR" .my-hooks
 test_expect_success 'refresh with core.hooksPath' '
     echo "pre-commit-hook-path-limiting-success" >>file &&
-    stg refresh file
+    stg refresh file &&
     assert_pre_commit_hook_did_run
 '
 mv .my-hooks "$HOOKDIR"
@@ -93,13 +93,13 @@ EOF
 
 test_expect_success 'refresh --no-verify with failing hook' '
     echo "no-verify pre-commit-hook-fail" >>file &&
-    stg refresh --no-verify
+    stg refresh --no-verify &&
     assert_pre_commit_hook_did_not_run
 '
 
 test_expect_success 'refresh --no-verify with path limiting, failing hook' '
     echo "no-verify pre-commit-hook-path-limiting-fail" >>file &&
-    stg refresh file --no-verify
+    stg refresh file --no-verify &&
     assert_pre_commit_hook_did_not_run
 '
 
@@ -107,7 +107,7 @@ test_expect_success 'refresh with failing hook' '
     echo "pre-commit-hook-fail" >>file &&
     command_error stg refresh 2>err &&
     grep -e "\`pre-commit\` hook returned 1" err &&
-    git reset HEAD
+    git reset HEAD &&
     assert_pre_commit_hook_did_run
 '
 
@@ -115,20 +115,20 @@ test_expect_success 'refresh with path limiting, failing hook' '
     echo "pre-commit-hook-path-limiting-fail" >>file &&
     command_error stg refresh file 2>err &&
     grep -e "\`pre-commit\` hook returned 1" err &&
-    git reset HEAD
+    git reset HEAD &&
     assert_pre_commit_hook_did_run
 '
 
 chmod -x "$HOOK"
 test_expect_success 'refresh --no-verify with non-executable hook' '
     echo "no-verify pre-commit-hook-non-executable" >>file &&
-    stg refresh --no-verify
+    stg refresh --no-verify &&
     assert_pre_commit_hook_did_not_run
 '
 
-test_expect_success 'refresh with non-executable hook' '
+test_expect_success !MINGW 'refresh with non-executable hook' '
     echo "pre-commit-hook-non-executable" >>file &&
-    stg refresh
+    stg refresh &&
     assert_pre_commit_hook_did_not_run
 '
 
@@ -146,28 +146,28 @@ EOF
 test_expect_success 'refresh --no-verify with failing hook that modifies file' '
     echo "no-verify pre-commit-hook-no-remove-whitespace  " >>file &&
     stg refresh --no-verify &&
-    [ "$(tail -1 file)" = "no-verify pre-commit-hook-no-remove-whitespace  " ]
+    [ "$(tail -1 file)" = "no-verify pre-commit-hook-no-remove-whitespace  " ] &&
     assert_pre_commit_hook_did_not_run
 '
 
 test_expect_success 'refresh --no-verify with path limiting, failing hook that modifies file' '
     echo "no-verify pre-commit-hook-path-limiting-no-remove-whitespace  " >>file &&
     stg refresh file --no-verify &&
-    [ "$(tail -1 file)" = "no-verify pre-commit-hook-path-limiting-no-remove-whitespace  " ]
+    [ "$(tail -1 file)" = "no-verify pre-commit-hook-path-limiting-no-remove-whitespace  " ] &&
     assert_pre_commit_hook_did_not_run
 '
 
 test_expect_success 'refresh with succeeding hook, does not modify file' '
     echo "pre-commit-hook-no-whitespace" >>file &&
     stg refresh &&
-    [ "$(tail -1 file)" = "pre-commit-hook-no-whitespace" ]
+    [ "$(tail -1 file)" = "pre-commit-hook-no-whitespace" ] &&
     assert_pre_commit_hook_did_run
 '
 
 test_expect_success 'refresh with path limiting, succeeding hook, does not modify file' '
     echo "pre-commit-hook-path-limiting-no-whitespace" >>file &&
     stg refresh file &&
-    [ "$(tail -1 file)" = "pre-commit-hook-path-limiting-no-whitespace" ]
+    [ "$(tail -1 file)" = "pre-commit-hook-path-limiting-no-whitespace" ] &&
     assert_pre_commit_hook_did_run
 '
 
@@ -177,13 +177,13 @@ test_expect_success 'refresh with failing hook that modifies file' '
     grep -e "\`pre-commit\` hook returned 1" err &&
     [ "$(git diff --name-only)" = "file" ] &&
     [ "$(git diff --cached --name-only)" = "file" ] &&
-    [ "$(tail -1 file)" = "pre-commit-hook-remove-whitespace" ]
+    [ "$(tail -1 file)" = "pre-commit-hook-remove-whitespace" ] &&
     assert_pre_commit_hook_did_run
 '
 
 test_expect_success 'refresh again after adding modified files to index' '
-    stg add file
-    stg refresh
+    stg add file &&
+    stg refresh &&
     assert_pre_commit_hook_did_run
 '
 
@@ -202,7 +202,7 @@ test_expect_success 'refresh with failing hook that modifies file, adds to index
     echo "pre-commit-hook-remove-whitespace-add-index  " >>file &&
     stg refresh &&
     [ "$(tail -1 file)" = "pre-commit-hook-remove-whitespace-add-index" ] &&
-    git diff-index --quiet HEAD
+    git diff-index --quiet HEAD &&
     assert_pre_commit_hook_did_run
 '
 
@@ -210,7 +210,7 @@ test_expect_success 'refresh with path limiting, failing hook that modifies file
     echo "pre-commit-hook-remove-whitespace-add-index  " >>file &&
     stg refresh file &&
     [ "$(tail -1 file)" = "pre-commit-hook-remove-whitespace-add-index" ] &&
-    git diff-index --quiet HEAD
+    git diff-index --quiet HEAD &&
     assert_pre_commit_hook_did_run
 '
 
