@@ -4,67 +4,65 @@ test_description='Simple test cases for "stg reset"'
 
 . ./test-lib.sh
 
-# Ignore our own output files.
-cat >> .git/info/exclude <<EOF
-/expected.txt
-EOF
-
 test_expect_success 'Initialize StGit stack with three patches' '
-    stg init &&
-    echo 000 >> a &&
+    # Ignore our own output files.
+    cat >>.git/info/exclude <<-\EOF &&
+	/expected.txt
+	EOF
+    echo 000 >>a &&
     stg add a &&
     git commit -m a &&
-    echo 111 >> a &&
+    echo 111 >>a &&
     git commit -a -m p1 &&
-    echo 222 >> a &&
+    echo 222 >>a &&
     git commit -a -m p2 &&
-    echo 333 >> a &&
+    echo 333 >>a &&
     git commit -a -m p3 &&
     stg uncommit -n 3 &&
     stg pop
 '
 
-cat > expected.txt <<EOF
-000
-111
-EOF
 test_expect_success 'Pop one patch ...' '
     stg pop &&
     test "$(echo $(stg series --all))" = "> p1 - p2 - p3" &&
+    cat >expected.txt <<-\EOF &&
+	000
+	111
+	EOF
     test_cmp expected.txt a
 '
 
-cat > expected.txt <<EOF
-000
-111
-222
-EOF
 test_expect_success '... and undo it' '
     stg reset refs/stacks/master^~1 &&
     test "$(echo $(stg series --all))" = "+ p1 > p2 - p3" &&
+    cat >expected.txt <<-\EOF &&
+	000
+	111
+	222
+	EOF
     test_cmp expected.txt a
 '
 
-cat > expected.txt <<EOF
-000
-111
-222
-333
-EOF
 test_expect_success 'Push one patch ...' '
     stg push &&
     test "$(echo $(stg series --all))" = "+ p1 + p2 > p3" &&
+    cat >expected.txt <<-\EOF &&
+	000
+	111
+	222
+	333
+	EOF
     test_cmp expected.txt a
 '
 
-cat > expected.txt <<EOF
-000
-111
-222
-EOF
 test_expect_success '... and undo it' '
     stg reset refs/stacks/master^~1 &&
     test "$(echo $(stg series --all))" = "+ p1 > p2 - p3" &&
+    cat >expected.txt <<-\EOF &&
+	000
+	111
+	222
+	EOF
     test_cmp expected.txt a
 '
 
@@ -99,13 +97,13 @@ test_expect_success '... and undo the unhiding' '
     stg unhide p3
 '
 
-cat > expected.txt <<EOF
-000
-111
-EOF
 test_expect_success 'Delete two patches ...' '
     stg delete p2 p3 &&
     test "$(echo $(stg series --all))" = "> p1" &&
+    cat >expected.txt <<-\EOF &&
+	000
+	111
+	EOF
     test_cmp expected.txt a
 '
 
@@ -121,39 +119,39 @@ test_expect_success '... then undo the first undo ...' '
     test_cmp expected.txt a
 '
 
-cat > expected.txt <<EOF
-000
-111
-222
-EOF
 test_expect_success '... and undo the other deletion' '
     stg reset refs/stacks/master^~3 p2 &&
     stg push p2 &&
     test "$(echo $(stg series --all))" = "+ p1 > p2" &&
+    cat >expected.txt <<-\EOF &&
+	000
+	111
+	222
+	EOF
     test_cmp expected.txt a
 '
 
-cat > expected.txt <<EOF
-000
-111
-222
-ggg
-EOF
 test_expect_success 'Refresh a patch ...' '
-    echo ggg >> a &&
+    echo ggg >>a &&
     stg refresh &&
     test "$(echo $(stg series --all))" = "+ p1 > p2" &&
+    cat >expected.txt <<-\EOF &&
+	000
+	111
+	222
+	ggg
+	EOF
     test_cmp expected.txt a
 '
 
-cat > expected.txt <<EOF
-000
-111
-222
-EOF
 test_expect_success '... and undo the refresh' '
     stg reset refs/stacks/master^~2 &&
     test "$(echo $(stg series --all))" = "+ p1 > p2" &&
+    cat >expected.txt <<-\EOF &&
+	000
+	111
+	222
+	EOF
     test_cmp expected.txt a
 '
 
