@@ -38,7 +38,7 @@ test_expect_success 'Initialize the StGit repository' '
 
 test_expect_success 'No pick args' '
     general_error stg pick 2>err &&
-    grep "The following required arguments were not provided" err
+    grep "the following required arguments were not provided" err
 '
 
 test_expect_success 'Pick --name with multiple patches' '
@@ -87,7 +87,7 @@ test_expect_success 'Pick --noapply several patches' '
 
 test_expect_success 'Pick --file without --fold' '
     general_error stg pick --file d D 2>err &&
-    grep "The following required arguments were not provided" err &&
+    grep "the following required arguments were not provided" err &&
     rm err
 '
 
@@ -130,7 +130,7 @@ test_expect_success 'Pick --revert' '
 
 test_expect_success 'Pick with empty result' '
     stg pick -B foo A &&
-    stg series -e | grep -E "0> A-1" &&
+    stg series -e | grep -F "*> A-1" &&
     stg delete A-1
 '
 
@@ -155,7 +155,7 @@ test_expect_success 'Pick --update' '
 test_expect_success 'Pick --update without applied patches' '
     stg pop -a &&
     command_error stg pick --update -B foo E 2>err &&
-    grep "No patches applied" err &&
+    grep "no patches applied" err &&
     rm err
 '
 
@@ -179,16 +179,16 @@ test_expect_success 'Pick commit with expose' '
 
 test_expect_success 'Pick too many commits' '
     stg pick --ref-branch foo $(cat C-id) D-foo &&
-    test "$(echo $(stg series --applied --noprefix))" = "C2 c-1 d-1" &&
+    test "$(echo $(stg series --applied --noprefix))" = "C2 c-1 D-foo" &&
     test "$(echo $(stg series --unapplied --noprefix))" = "A B C D" &&
-    stg delete c-1 d-1
+    stg delete c-1 D-foo
 '
 
 test_expect_success 'Pick with conflict' '
     rm C-id &&
     stg push A &&
     conflict stg pick foo:AAA 2>err &&
-    grep "Merge conflicts" err &&
+    grep "merge conflicts" err &&
     rm err &&
     test "$(stg top)" = "AAA" &&
     test "$(echo $(stg series -A --noprefix))" = "C2 A AAA" &&
